import { State } from './core/enum/state';
import { ITicker } from './core/interfaces/ITicker';
/**
 * Main Fatina Ticker
 * Parent of all the normal tween and sequence
 *
 * @export
 * @class Ticker
 * @extends {EventList}
 * @implements {ITicker}
 */
export declare class Ticker implements ITicker {
    state: State;
    /**
     * @private
     */
    private timescale;
    elapsed: number;
    duration: number;
    /**
     * @private
     */
    private tickCb;
    /**
     * @private
     */
    private readonly ticks;
    /**
     * @private
     */
    private readonly newTicks;
    /**
     * @private
     */
    private parent;
    /**
     * @private
     */
    private dt;
    setParent(parent: ITicker, tick: (dt: number) => void): void;
    /**
     * Method used to change the timescale
     *
     * @param {number} scale
     */
    setTimescale(scale: number): void;
    /**
     * Method used by the child to be updated
     *
     * @param {(dt: number) => void} cb
     */
    addTick(cb: (dt: number) => void): void;
    /**
     * Method used by the child to not receive update anymore
     *
     * @param {(dt: number) => void} cb
     */
    removeTick(cb: (dt: number) => void): void;
    /**
     * Method used to tick all the child (tick listeners)
     *
     * @param {number} dt
     * @returns
     */
    tick(dt: number): void;
    start(): void;
    pause(): void;
    resume(): void;
    kill(): void;
    skip(): void;
    reset(): void;
    get isIdle(): boolean;
    get isRunning(): boolean;
    get isFinished(): boolean;
    get isPaused(): boolean;
}
